Class: Hash
Instance Method Summary collapse
-
#keys=(keys) ⇒ Object
TODO: for doc - this is usefull to fill an hash wich have a default proc.
TODO: for doc - this is usefull to fill an hash wich have a default proc.